message_string

Macro message_string 

macro_rules! message_string {
    ($literal:literal) => { ... };
}
Returns an owned public-facing message.

With the default obfuscate feature this uses the crate’s current obfuscation backend. With default features disabled this allocates from the literal.

Accepts only a string literal; see message! for the rationale.

let owned = redacted_error::message_string!("request failed");
assert_eq!(owned, String::from("request failed"));