macro_rules! detail {
($($arg:tt)*) => { ... };
}Expand description
Formats runtime diagnostic detail in debug builds and strips it in release builds.
In release builds the format arguments are not evaluated — any side effects in the argument expressions are skipped.
let detail = redacted_error::detail!("addr={}", "127.0.0.1");
assert_eq!(detail, "addr=127.0.0.1");